SELECT 100/aiomysql - Criterion.rs

## SELECT 100/aiomysql

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0122235 | 0.0126658 | 0.0121878
Mean | 16.912 ms | 17.097 ms | 17.290 ms
Std. Dev. | 822.39 µs | 972.78 µs | 1.1143 ms
Median | 16.488 ms | 16.813 ms | 17.150 ms
MAD | 529.94 µs | 898.67 µs | 1.1964 ms

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.